dpm: Dirichlet process mixture model

Description Usage Arguments Details Value Warning Author(s) References Examples

Description

Estimates the parameters of a Dirichlet process mixture model.

Usage

1
  dpm.fit(y, xd = NULL, L, prior, nsim, nburn, nthin = 1, start = NULL, scale = TRUE)

Arguments

y

A numeric vector or matrix containing the data. If a matrix is supplied, then the first column must be the response variable.

xd

An optional numeric vector or matrix containing the binary covariates.

L

An integer greater or equal than 2 representing the maximum number of components to be used in the truncated stick-breaking construction.

prior

A list containing the hyperparameters of the Dirichlet process (DP) baseline distribution and its precision parameter, α. The list must specify the following elements: mu_0, V_0, nu_0, Psi_0, a_pi, b_pi and alpha. See 'Details' for further specification.

nsim

An integer specifying the number of MCMC iterations to be performed.

nburn

An integer specifying the number of obervations for the burn-in period. It must be less than nsim.

nthin

An optional integer specifying the thinning on the MCMC sample.

start

An optional list containing the initial values for each parameter. See 'Details'.

scale

An optional logical argument specifying whether the data should be centered and standardrized or not. The default value is TRUE.

Details

Here goes the details.

Value

A list containing:

y

The original data.

params

A list containing the posterior sample of the parameters.

Warning

Be careful setting starting values, the function do not test for a correct structure of the parameters.

Author(s)

Javier E. Garrido Guillén

References

Escobar, M. D. & West, M. (1995), “Bayesian density estimation and inference using mixtures”, Journal of the American Statistical Association 90(430), 577–588.
Ferguson, T. S. (1974), “Prior distributions on spaces of probability measures”, The Annals of Statistics 2(4), 615–629.
Ishwaran, H. & Zarepour, M. (2000), “Markov chain Monte Carlo in approximate Dirichlet and beta two-parameter process hierarchical models”, Biometrika 87(2), 371–390.
Richardson, S. & Green, P. J. (1997), “On Bayesian analysis of mixtures with an unknown number of components (with discussion)”, Journal of the Royal Statistical Society, Series B 59(4), 731–792.

Examples

1
  Some examples go here.

javier-gg/OverlapCoefficient documentation built on July 21, 2020, 12:14 a.m.